ManagerDailyBriefActionKindCode

Enum ManagerDailyBriefActionKindCode 

pub enum ManagerDailyBriefActionKindCode {
    ReviewDemandAgainstStaffingPlan,
    ResolveCheckoutException,
    ApproveRetentionFollowUpDraft,
    InvestigateSourceDataQualityIssue,
}
Persisted manager daily-brief actions that can produce labor-minute evidence.

Variants



ReviewDemandAgainstStaffingPlan

Stable storage code for review demand against staffing plan.



ResolveCheckoutException

Stable storage code for resolve checkout exception.



ApproveRetentionFollowUpDraft

Stable storage code for approve retention follow up draft.



InvestigateSourceDataQualityIssue

Stable storage code for investigate source data quality issue.