ServiceOfferingRecordBuilder

Struct ServiceOfferingRecordBuilder 

pub struct ServiceOfferingRecordBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ServiceOfferingRecordBuilder<S>

pub fn build(self) -> ServiceOfferingRecord
where S: IsComplete,

Finish building and return the requested object

pub fn service_kind( self, value: ServiceOfferingKindCode, ) -> ServiceOfferingRecordBuilder<SetServiceKind<S>>
where S::ServiceKind: IsUnset,

Required.

Discriminator indicating which service-line fields are meaningful.

pub fn boarding_accommodation( self, value: AccommodationCode, ) -> ServiceOfferingRecordBuilder<SetBoardingAccommodation<S>>
where S::BoardingAccommodation: IsUnset,

Optional (Some / Option setters). Boarding room or suite type for a boarding offering.

pub fn maybe_boarding_accommodation( self, value: Option<AccommodationCode>, ) -> ServiceOfferingRecordBuilder<SetBoardingAccommodation<S>>
where S::BoardingAccommodation: IsUnset,

Optional (Some / Option setters). Boarding room or suite type for a boarding offering.

pub fn boarding_included_care( self, value: Vec<CareFeatureCode>, ) -> ServiceOfferingRecordBuilder<SetBoardingIncludedCare<S>>
where S::BoardingIncludedCare: IsUnset,

Optional (Some / Option setters). Default: <Vec<boarding::CareFeatureCode> as Default>::default().

Included care features bundled with a boarding offering.

pub fn maybe_boarding_included_care( self, value: Option<Vec<CareFeatureCode>>, ) -> ServiceOfferingRecordBuilder<SetBoardingIncludedCare<S>>
where S::BoardingIncludedCare: IsUnset,

Optional (Some / Option setters). Default: <Vec<boarding::CareFeatureCode> as Default>::default().

Included care features bundled with a boarding offering.

pub fn boarding_add_ons( self, value: Vec<AddOnCode>, ) -> ServiceOfferingRecordBuilder<SetBoardingAddOns<S>>
where S::BoardingAddOns: IsUnset,

Optional (Some / Option setters). Default: <Vec<boarding::AddOnCode> as Default>::default().

Optional boarding add-ons available for the offering.

pub fn maybe_boarding_add_ons( self, value: Option<Vec<AddOnCode>>, ) -> ServiceOfferingRecordBuilder<SetBoardingAddOns<S>>
where S::BoardingAddOns: IsUnset,

Optional (Some / Option setters). Default: <Vec<boarding::AddOnCode> as Default>::default().

Optional boarding add-ons available for the offering.

pub fn daycare_format( self, value: FormatCode, ) -> ServiceOfferingRecordBuilder<SetDaycareFormat<S>>
where S::DaycareFormat: IsUnset,

Optional (Some / Option setters). Daycare play or day-boarding format represented by the offering.

pub fn maybe_daycare_format( self, value: Option<FormatCode>, ) -> ServiceOfferingRecordBuilder<SetDaycareFormat<S>>
where S::DaycareFormat: IsUnset,

Optional (Some / Option setters). Daycare play or day-boarding format represented by the offering.

pub fn daycare_eligibility_rules( self, value: Vec<EligibilityRuleCode>, ) -> ServiceOfferingRecordBuilder<SetDaycareEligibilityRules<S>>
where S::DaycareEligibilityRules: IsUnset,

Optional (Some / Option setters). Default: <Vec<daycare::EligibilityRuleCode> as Default>::default().

Eligibility requirements that must be satisfied before daycare use.

pub fn maybe_daycare_eligibility_rules( self, value: Option<Vec<EligibilityRuleCode>>, ) -> ServiceOfferingRecordBuilder<SetDaycareEligibilityRules<S>>
where S::DaycareEligibilityRules: IsUnset,

Optional (Some / Option setters). Default: <Vec<daycare::EligibilityRuleCode> as Default>::default().

Eligibility requirements that must be satisfied before daycare use.

pub fn grooming_service( self, value: ServiceCode, ) -> ServiceOfferingRecordBuilder<SetGroomingService<S>>
where S::GroomingService: IsUnset,

Optional (Some / Option setters). Grooming service represented by the offering.

pub fn maybe_grooming_service( self, value: Option<ServiceCode>, ) -> ServiceOfferingRecordBuilder<SetGroomingService<S>>
where S::GroomingService: IsUnset,

Optional (Some / Option setters). Grooming service represented by the offering.

pub fn grooming_cadence_weeks( self, value: StoredCadenceWeeks, ) -> ServiceOfferingRecordBuilder<SetGroomingCadenceWeeks<S>>
where S::GroomingCadenceWeeks: IsUnset,

Optional (Some / Option setters). Recommended grooming repeat cadence in weeks.

pub fn maybe_grooming_cadence_weeks( self, value: Option<StoredCadenceWeeks>, ) -> ServiceOfferingRecordBuilder<SetGroomingCadenceWeeks<S>>
where S::GroomingCadenceWeeks: IsUnset,

Optional (Some / Option setters). Recommended grooming repeat cadence in weeks.

pub fn training_program( self, value: ProgramRecord, ) -> ServiceOfferingRecordBuilder<SetTrainingProgram<S>>
where S::TrainingProgram: IsUnset,

Optional (Some / Option setters). Training program represented by the offering.

pub fn maybe_training_program( self, value: Option<ProgramRecord>, ) -> ServiceOfferingRecordBuilder<SetTrainingProgram<S>>
where S::TrainingProgram: IsUnset,

Optional (Some / Option setters). Training program represented by the offering.

pub fn retail_partner( self, value: PartnerCode, ) -> ServiceOfferingRecordBuilder<SetRetailPartner<S>>
where S::RetailPartner: IsUnset,

Optional (Some / Option setters). Retail partner product represented by the offering.

pub fn maybe_retail_partner( self, value: Option<PartnerCode>, ) -> ServiceOfferingRecordBuilder<SetRetailPartner<S>>
where S::RetailPartner: IsUnset,

Optional (Some / Option setters). Retail partner product represented by the offering.

pub fn retail_product_category( self, value: ProductCategoryCode, ) -> ServiceOfferingRecordBuilder<SetRetailProductCategory<S>>
where S::RetailProductCategory: IsUnset,

Optional (Some / Option setters). Retail category used for merchandising and upsell logic.

pub fn maybe_retail_product_category( self, value: Option<ProductCategoryCode>, ) -> ServiceOfferingRecordBuilder<SetRetailProductCategory<S>>
where S::RetailProductCategory: IsUnset,

Optional (Some / Option setters). Retail category used for merchandising and upsell logic.