StoredSourceRecordRefBuilder

Struct StoredSourceRecordRefBuilder 

pub struct StoredSourceRecordRefBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> StoredSourceRecordRefBuilder<S>

pub fn build(self) -> StoredSourceRecordRef
where S: IsComplete,

Finish building and return the requested object

pub fn system(self, value: String) -> StoredSourceRecordRefBuilder<SetSystem<S>>
where S::System: IsUnset,

Required.

Source system name, for example gingr, used to keep provider facts quarantined by origin.

pub fn record_type( self, value: String, ) -> StoredSourceRecordRefBuilder<SetRecordType<S>>
where S::RecordType: IsUnset,

Required.

Provider record collection or endpoint that produced the evidence.

pub fn record_id( self, value: String, ) -> StoredSourceRecordRefBuilder<SetRecordId<S>>
where S::RecordId: IsUnset,

Required.

Provider-native identifier for the source record.

pub fn observed_at( self, value: String, ) -> StoredSourceRecordRefBuilder<SetObservedAt<S>>
where S::ObservedAt: IsUnset,

Required.

Timestamp when the adapter observed this provider fact.

pub fn adapter_version( self, value: String, ) -> StoredSourceRecordRefBuilder<SetAdapterVersion<S>>
where S::AdapterVersion: IsUnset,

Required.

Adapter or fixture version that interpreted the source record.